#!/usr/local/bin/perl
#
# $Id: exec.t,v 1.5 2003/10/14 23:58:47 mpeppler Exp $

use lib 'blib/lib';
use lib 'blib/arch';

use lib 't';

use _test;

use strict;
use Test::More;

BEGIN { plan tests=> 9;}

BEGIN {use_ok('DBI', qw(:sql_types));}

#DBI->trace(3);

my ($Uid, $Pwd, $Srv, $Db) = _test::get_info();

my $dbh = DBI->connect("dbi:FreeTDS:server=$Srv;database=$Db", $Uid, $Pwd, {PrintError=>1});
#exit;
ok(defined($dbh), 'Connect');

SKIP: {
    skip "EXEC with placeholders aren't supported with this version of FreeTDS", 7 unless $dbh->{syb_rpc_supported};

    my $sth = $dbh->prepare("exec sp_helpindex \@objname = ?");
    ok(defined($sth), 'Prepare');

    my $rc;

    $rc = $sth->execute("sysusers");
    ok($rc != -2, 'Execute');
    do {
	while(my $d = $sth->fetch) {
	    #	print "@$d\n";
	}
    } while($sth->{syb_more_results});

    $dbh->do("use tempdb");
    $dbh->do("set arithabort off");
#    $dbh->do("drop proc dbitest");
    $rc = $dbh->do(qq{
create proc dbitest \@one varchar(20), \@two int, \@three numeric(5,2), \@four smalldatetime, \@five float output
as
    select \@one, \@two, \@three, \@four
});

    ok(defined($rc), 'Proc create');

    $sth = $dbh->prepare("exec dbitest \@one = ?, \@two = ?, \@three = ?, \@four = ?, \@five = ? output");
#$rc = $sth->execute("one", 2, 3.2, "jan 1 2001", 5.4);
    $sth->bind_param(1, "one");
    $sth->bind_param(2, 2, SQL_INTEGER);
    $sth->bind_param(3, 3.2, SQL_DECIMAL);
    $sth->bind_param(4, "jan 1 2001");
    $sth->bind_param(5, 5.4, SQL_FLOAT);
    $rc = $sth->execute();
    ok($rc != -2, 'Execute dbitest');
    do {
	while(my $d = $sth->fetch) {
	    print "@$d\n";
	}
    } while($sth->{syb_more_results});

    $rc = $sth->execute("one", 25, 333.2, "jan 1 2001", 5.4);
    ok($rc != -2, 'Execute dbitest 2');
    do {
	while(my $d = $sth->fetch) {
	    print "@$d\n";
	}
    } while($sth->{syb_more_results});


    $rc = $sth->execute(undef, 25, 3.2234, "jan 3 2001", 5.4);
    ok($rc != -2, 'Execute dbitest 3');
    my @out = $sth->func('syb_output_params');
    ok($out[0] == 5.4, 'Output param');
#print "@out\n";
#do {
#    local $^W = 0;
#    while(my $d = $sth->fetch) {
#	print "@$d\n";
#    }
#} while($sth->{syb_more_results});

    $dbh->do("drop proc dbitest");
}

