#!/usr/local/bin/perl
#
# $Id: fail.t,v 1.5 2003/10/14 23:58:47 mpeppler Exp $

use lib 'blib/lib';
use lib 'blib/arch';

use lib 't';

use _test;

use strict;
use Test::More;

BEGIN { plan tests => 13;}
BEGIN { use_ok('DBI'); }

my ($Uid, $Pwd, $Srv, $Db) = _test::get_info();

my $dbh = DBI->connect("dbi:FreeTDS:server=$Srv;database=$Db", $Uid, $Pwd, {PrintError => 0});

die "Unable for connect to $Srv: $DBI::errstr" unless $dbh;

my $rc;

my $sth = $dbh->prepare("
-- MS-SQL will not fail the first request even if a later query fails
-- in the same batch.
-- select * from sysusers   
select * from no_such_table
select * from master..sysdatabases
");
$rc = $sth->execute;
ok(!defined($rc), 'Multi-statement fail');
$sth->finish;
$sth = $dbh->prepare("select * from sysusers\n");
$rc = $sth->execute;
ok(defined($rc), 'Single statement');
while(my $d = $sth->fetch) {
    ;
}
ok(1 == 1, 'Fetch loop');	# XXX

$rc = $dbh->do("create table #test(constraint TEST check(two != three), one int not null primary key, two int not null, three int not null)");
ok(defined($rc), 'Temp table creation');

SKIP: {
    skip '?-style placeholders not supported', 3 unless $dbh->{syb_dynamic_supported};

    $sth = $dbh->prepare("insert #test (one, two, three) values(?,?,?)");
    $rc = $sth->execute(3, 4, 5);
    ok(defined($rc), 'Dynamic');
    $rc = $sth->execute(3, 4, 5);
    ok(!defined($rc), 'Dynmamic');
    $rc = $sth->execute(5, 3, 3);
    ok(!defined($rc), 'Dynamic');
}

$sth = $dbh->prepare("
insert #test(one, two, three) values (1, 2, 3)
insert #test(one, two, three) values (4, 5, 6)
insert #test(one, two, three) values (1, 2, 3)
insert #test(one, two, three) values (8, 9, 10)
");
$rc = $sth->execute;
ok(!defined($rc), 'Literal inserts');

$sth = $dbh->prepare("select * from #test");
$rc = $sth->execute;
ok(defined($rc), 'select');

while(my $d = $sth->fetch) {
    print "@$d\n";
}
ok(1 == 1, 'Fetch loop');

$sth = $dbh->prepare("
insert #test(one, two, three) values (11, 12, 13)
select * from #test
insert #test(one, two, three) values (11, 12, 13)
");
$rc = $sth->execute;
ok(defined($rc), 'multi-insert');
do {
    while(my $d = $sth->fetch) {
	print "@$d\n";
    }
} while($sth->{syb_more_results});
ok(1 == 1, 'Fetch loop');

$dbh->do("drop table #test");



