#!/usr/local/bin/perl
#
# $Id: main.t,v 1.6 2003/10/14 23:58:47 mpeppler Exp $

use lib 'blib/lib';
use lib 'blib/arch';

use lib 't';

use _test;

use strict;
use Test::More;

BEGIN { plan tests => 17;}
BEGIN { use_ok('DBI'); }

my ($Uid, $Pwd, $Srv, $Db) = _test::get_info();

my($switch) = DBI->internal;

print "Switch: $switch->{'Attribution'}, $switch->{'Version'}\n";

print "Available Drivers: ",join(", ",DBI->available_drivers()),"\n";

my $dbh = DBI->connect("dbi:FreeTDS:server=$Srv;database=$Db", $Uid, $Pwd, {PrintError => 0});

die "Unable for connect to $Srv: $DBI::errstr"
    unless $dbh;

print "OpenClient version $dbh->{syb_oc_version}\n";

my $rc;

$rc = $dbh->do("use master");
ok($rc, 'Use master');

my $sth;

$sth = $dbh->prepare("select * from sysusers");
ok(defined($sth), 'Prepare');

$rc = $sth->execute;
ok(defined($rc), 'Execute');
if($rc) {
    print "Fields: $sth->{NUM_OF_FIELDS}\n";
    print "Names: @{$sth->{NAME}}\n";
    print "Null:  @{$sth->{NULLABLE}}\n";
}
my $rows = 0;
my @dat;
while(@dat = $sth->fetchrow) {
    ++$rows;
    foreach (@dat) {
	$_ = '' unless defined $_;
    }
    print "@dat\n";
}
ok($rows == $sth->rows, 'Check rows');
undef $sth;
$sth = $dbh->prepare("select * from sys_users");
ok(defined($sth), 'Prepare');

$rc = $sth->execute;
ok(!defined($rc), 'Error query');
ok($DBI::err == 208, 'Error number');
$sth = $dbh->prepare("select * from sysusers");
ok(defined($sth), 'Prepare');

$rc = $sth->execute;
ok(defined($rc), 'Execute');
my @fields = @{$sth->{NAME}};
$rows = 0;
my $d;
my $ok = 1;
while($d = $sth->fetchrow_hashref) {
    ++$rows;
    foreach (@fields) {
	if(!exists($d->{$_})) {
	    $ok = 0;
	}
	my $t = $d->{$_} || '';
	print "$t ";
    }
    print "\n";
}
ok($ok == 1, 'Check columns in ouput');
ok($rows == $sth->rows, 'Check rows');

undef $sth;

$dbh->{LongReadLen} = 32000;

$dbh->{syb_quoted_identifier} = 1;

$rc = $dbh->do('create table #tmp("TR Number" int, "Answer Code" char(2))');
ok(defined($rc), 'quoted identifier');

$rc = $dbh->do(qq(insert #tmp ("TR Number", "Answer Code") values(123, 'B')));
ok(defined($rc), 'Insert with quoted identifier');

$dbh->{syb_quoted_identifier} = 0;

# Test multiple result sets, varying column names
$sth = $dbh->prepare("
select uid, name from sysusers where uid = 0
select spid, kpid from master..sysprocesses where spid = \@\@spid
");
$rc = $sth->execute;
ok(defined($rc), 'Execute');

my $result_set = 0;
do {
    while(my $row = $sth->fetchrow_hashref) {
	if($result_set == 1) {
	    ok(defined($row->{spid}), 'Check column in second result set');
	}
    }
    ++$result_set;
} while($sth->{syb_more_results});


{ local $SIG{__WARN__} = sub { print @_; };
  $sth = $dbh->prepare("select * from master..sysprocesses");
  $sth->execute;

  $dbh->{syb_rowcount} = 5;
  ok($dbh->err == 20001, 'Check fail code for set rowcount with active query');
  $sth->finish;
}


$dbh->disconnect;


