#!/usr/local/bin/perl
#
# $Id: place.t,v 1.4 2003/10/14 23:58:47 mpeppler Exp $

use lib 'blib/lib';
use lib 'blib/arch';

use lib 't';

use _test;

use strict;
use Test::More;

BEGIN { plan tests => 11;}
BEGIN { use_ok('DBI'); }

#DBI->trace(3);

my ($Uid, $Pwd, $Srv, $Db) = _test::get_info();

my $dbh = DBI->connect("dbi:FreeTDS:server=$Srv;database=$Db", $Uid, $Pwd, {PrintError => 0});

die "Unable for connect to $Srv: $DBI::errstr"
    unless $dbh;

SKIP: {
    skip "?-style placeholders aren't supported in this version of FreeTDS", 10
	unless $dbh->{syb_dynamic_supported};

    my $rc;

    $rc = $dbh->do("create table #t(string varchar(20), date datetime, val float, other_val numeric(9,3))");
    ok(defined($rc), 'Create temp table');

    my $sth = $dbh->prepare("insert #t values(?, ?, ?, ?)");
    ok(defined($sth), 'prepare');

    $rc = $sth->execute("test", "Jan 3 1998", 123.4, 222.3334);
    ok(defined($rc), 'Execute');

    $rc = $sth->execute("other test", "Jan 25 1998", 4445123.4, 2);
    ok(defined($rc), 'Execute');

    $rc = $sth->execute("test", "Feb 30 1998", 123.4, 222.3334);
    ok(defined($rc), 'Execute');

    $sth = $dbh->prepare("select * from #t where date > ? and val > ?");
    ok(defined($sth), 'prepare');

    $rc = $sth->execute('Jan 1 1998', 120);
    ok(defined($rc), 'Execute');

    my $row;
    my $count = 0;

    while($row = $sth->fetch) {
	print "@$row\n";
	++$count;
    }

    ok($count == 2, 'rows fetched');

    $rc = $sth->execute('Jan 1 1998', 140);
    ok(defined($rc), 'Execute');
    
    $count = 0;

    while($row = $sth->fetch) {
	print "@$row\n";
	++$count;
    }
    
    ok($count == 1, 'rows fetched');

    $dbh->do("create table #t2(id int, c varchar(10))");
    $dbh->do("
insert #t2 values(1, 'one')
insert #t2 values(2, 'two')
");
    $sth = $dbh->prepare("select id, c from #t2 where id = ?");
    $sth->execute(1);
#DBI->trace(3);
    $row = $sth->fetch;
    $sth->finish;
    $sth->execute(2);
    $row = $sth->fetch;
    $sth->finish;
}
 
$dbh->disconnect;
    
exit(0);
